==> haskell-hie-compat-0.3.0.0-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hie-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hie-compat
version:              0.3.0.0
visibility:           public
id:                   hie-compat-0.3.0.0-HtRpwVRm0jbBmBGDkwMYdm
key:                  hie-compat-0.3.0.0-HtRpwVRm0jbBmBGDkwMYdm
license:              Apache-2.0
maintainer:           zubin.duggal@gmail.com
author:               Zubin Duggal
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/hie-compat#readme

synopsis:             HIE files for GHC 8.6 and other HIE file backports
description:
    Backports for HIE files to GHC 8.6, along with a few other backports
    of HIE file related fixes for ghcide.
    THIS DOES NOT LET YOU READ HIE FILES WITH MISMATCHED VERSIONS OF GHC

category:             Development
abi:                  7bc71cfa1448069bf315f7a00e8c7fd5
exposed:              True
exposed-modules:
    Compat.HieAst Compat.HieBin Compat.HieDebug Compat.HieTypes
    Compat.HieUtils

import-dirs:          /usr/lib/ghc-9.0.2/site-local/hie-compat-0.3.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hie-compat-0.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hie-compat
hs-libraries:         HShie-compat-0.3.0.0-HtRpwVRm0jbBmBGDkwMYdm
depends:
    array-0.5.4.0 base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1
    directory-1.3.6.2 filepath-1.4.2.1 ghc-9.0.2 ghc-boot-9.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-hie-compat/html/hie-compat.haddock
haddock-html:         /usr/share/doc/haskell-hie-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hie-compat-0.3.0.0-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hie-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hie-compat
version:              0.3.0.0
visibility:           public
id:                   hie-compat-0.3.0.0-J18lPJVEz9RKJxYK1ST1Nn
key:                  hie-compat-0.3.0.0-J18lPJVEz9RKJxYK1ST1Nn
license:              Apache-2.0
maintainer:           zubin.duggal@gmail.com
author:               Zubin Duggal
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/hie-compat#readme

synopsis:             HIE files for GHC 8.6 and other HIE file backports
description:
    Backports for HIE files to GHC 8.6, along with a few other backports
    of HIE file related fixes for ghcide.
    THIS DOES NOT LET YOU READ HIE FILES WITH MISMATCHED VERSIONS OF GHC

category:             Development
abi:                  66fffb443c76c3a328d538848b7fc564
exposed:              True
exposed-modules:
    Compat.HieAst Compat.HieBin Compat.HieDebug Compat.HieTypes
    Compat.HieUtils

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hie-compat-0.3.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hie-compat-0.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hie-compat
hs-libraries:         HShie-compat-0.3.0.0-J18lPJVEz9RKJxYK1ST1Nn
depends:
    array-0.5.4.0 base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    directory-1.3.6.2 filepath-1.4.2.2 ghc-9.2.8 ghc-boot-9.2.8
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-hie-compat/html/hie-compat.haddock
haddock-html:         /usr/share/doc/haskell-hie-compat/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
